==> apache-reef-0.11.0-incubating.tar.gz: apache-reef-0.11.0-incubating/lang/java/reef-wake/wake/src/main/java/org/apache/reef/wake/remote/impl/Subscription.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.wake.remote.impl;

/**
 * Subscription of a handler
 *
 * @param <T> type
 */
public class Subscription<T> implements AutoCloseable {

  private final HandlerContainer<T> container;
  private final T token;

  /**
   * Constructs a subscription
   *
   * @param token            the token for finding the subscription
   * @param handlerContainer the container managing handlers
   */
  public Subscription(T token, HandlerContainer<T> handlerContainer) {
    this.token = token;
    this.container = handlerContainer;
  }

  /**
   * Gets the token of this subscription
   *
   * @return the token of this subscription
   */
  public T getToken() {
    return token;
  }

  /**
   * Unsubscribes this subscription
   *
   * @throws Exception
   */
  @Override
  public void close() throws Exception {
    container.unsubscribe(this);
  }

}

==> apache-reef-0.12.0-incubating.tar.gz: apache-reef-0.12.0-incubating/lang/java/reef-wake/wake/src/main/java/org/apache/reef/wake/remote/impl/Subscription.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.wake.remote.impl;

/**
 * Subscription of a handler.
 *
 * @param <T> type
 */
public class Subscription<T> implements AutoCloseable {

  private final HandlerContainer<T> container;
  private final T token;

  /**
   * Constructs a subscription.
   *
   * @param token            the token for finding the subscription
   * @param handlerContainer the container managing handlers
   */
  public Subscription(final T token, final HandlerContainer<T> handlerContainer) {
    this.token = token;
    this.container = handlerContainer;
  }

  /**
   * Gets the token of this subscription.
   *
   * @return the token of this subscription
   */
  public T getToken() {
    return token;
  }

  /**
   * Unsubscribes this subscription.
   *
   * @throws Exception
   */
  @Override
  public void close() throws Exception {
    container.unsubscribe(this);
  }

}
